@@ -1,7 +1,7 @@
 /*********************************************************************
   Blosc - Blocked Shuffling and Compression Library
 
-  Copyright (c) 2021  The Blosc Development Team <blosc@blosc.org>
+  Copyright (c) 2021  Blosc Development Team <blosc@blosc.org>
   https://blosc.org
   License: BSD 3-Clause (see LICENSE.txt)
 
@@ -18,7 +18,11 @@
 #include <stdint.h>
 #include <stdio.h>
 
-#if defined __i386__ || defined _M_IX86 || defined __x86_64__ || defined _M_X64
+/* Do NOT auto-define SSSE3 based on _MSC_VER (clang-cl defines _MSC_VER). 
+Require the build system to enable SSSE3 via the appropriate compiler 
+flag (/arch:SSSE3 or -mssse3). */
+
+#if defined(HAVE_SSSE3)
 // SSSE3 code path for x64/x64
 #define CPU_HAS_SIMD 1
 #include <emmintrin.h>
